@@ -106,5 +106,51 @@ randomnessNTest <- function() {
 	dialogSuffix(rows=6, columns=1)
 }
 
+sigmaTest <- function() {
+    ## This function is developed from singleSampleTTest in Rcmdr and use function sigma.test in package TeachingDemos
+    ## To ensure that menu name is included in pot file
+    gettext("Single-Sample Chi-squared-Test...", domain="R-RcmdrPlugin.UCA")
+    defaults <- list (initial.x = NULL, initial.alternative = "two.sided", initial.level = ".95", initial.sigma = "1.0")
+    dialog.values <- getDialog ("sigmaTest", defaults)
+    initializeDialog(title = gettext("Single-Sample Chi-squared-Test", domain="R-RcmdrPlugin.UCA"))
+    xBox <- variableListBox(top, Numeric(), title = gettextRcmdr("Variable (pick one)"), initialSelection = varPosn(dialog.values$initial.x, "numeric"))
+    onOK <- function() {
+        x <- getSelection(xBox)
+        if (length(x) == 0) {
+            errorCondition(recall = sigmaTest, message = gettextRcmdr("You must select a variable."))
+            return()
+        }
+        alternative <- as.character(tclvalue(alternativeVariable))
+        level <- tclvalue(confidenceLevel)
+        sigma <- tclvalue(sigmaVariable)
+        putDialog("sigmaTest", list (initial.x = x, initial.alternative = alternative, initial.level = level, initial.sigma = sigma))
+        closeDialog()
+        doItAndPrint(paste("with(", ActiveDataSet (), ", (sigma.test(", x, ", alternative='", alternative, "', sigma=", sigma, ", conf.level=", level, ")))", sep = ""))
+        tkdestroy(top)
+        tkfocus(CommanderWindow())
+    }
+    OKCancelHelp(helpSubject = "sigma.test", reset = "sigmaTest", apply = "sigmaTest")
+    optionsFrame <- tkframe(top)
+    radioButtons(optionsFrame, name = "alternative", buttons = c("twosided", "less", "greater"), values = c("two.sided", "less", "greater"), labels = paste(gettext("Population variance", domain="R-RcmdrPlugin.UCA"), c("!= sigma0", "< sigma0", "> sigma0")), title = gettextRcmdr("Alternative Hypothesis"), initialValue = dialog.values$initial.alternative)
+    rightFrame <- tkframe(optionsFrame)
+    confidenceFrame <- tkframe(rightFrame)
+    confidenceLevel <- tclVar(dialog.values$initial.level)
+    confidenceField <- ttkentry(confidenceFrame, width = "6", textvariable = confidenceLevel)
+    sigmaFrame <- tkframe(rightFrame)
+    sigmaVariable <- tclVar(dialog.values$initial.sigma)
+    sigmaField <- ttkentry(sigmaFrame, width = "8", textvariable = sigmaVariable)
+    tkgrid(getFrame(xBox), sticky = "nw")
+    tkgrid(labelRcmdr(rightFrame, text = ""), sticky = "w")
+    tkgrid(labelRcmdr(sigmaFrame, text = gettext("Null hypothesis: sigma =", domain="R-RcmdrPlugin.UCA")),  sigmaField, sticky = "w", padx=c(10, 0))
+    tkgrid(sigmaFrame, sticky = "w")
+    tkgrid(labelRcmdr(confidenceFrame, text = gettextRcmdr("Confidence Level: ")), confidenceField, sticky = "w", padx=c(10, 0))
+    tkgrid(confidenceFrame, sticky = "w")
+    tkgrid(alternativeFrame, rightFrame, sticky = "nw")
+    tkgrid(optionsFrame, sticky="w")
+    tkgrid(buttonsFrame, columnspan = 2, sticky = "w")
+    tkgrid.configure(confidenceField, sticky = "e")
+    dialogSuffix()
+    }
+
 numeric.runs.test <- function(...) randtest.runs.test(...)
 twolevelfactor.runs.test <- function(...) tseries.runs.test(...)
